==> pointpos_api-0.2.0.tar.gz: test/table_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';

// tests for Table
void main() {
  var instance = new Table();

  group('test Table', () {
    // String id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // String tableGroup (default value: null)
    test('to test the property `tableGroup`', () async {
      // TODO
    });

    // String name (default value: null)
    test('to test the property `name`', () async {
      // TODO
    });

    // num pax (default value: null)
    test('to test the property `pax`', () async {
      // TODO
    });

    // String shape (default value: null)
    test('to test the property `shape`', () async {
      // TODO
    });

    // TableLocation location (default value: null)
    test('to test the property `location`', () async {
      // TODO
    });

    // DateTime createdAt (default value: null)
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // String createdBy (default value: null)
    test('to test the property `createdBy`', () async {
      // TODO
    });

    // DateTime updatedAt (default value: null)
    test('to test the property `updatedAt`', () async {
      // TODO
    });

    // String updatedBy (default value: null)
    test('to test the property `updatedBy`', () async {
      // TODO
    });

    // bool deleted (default value: null)
    test('to test the property `deleted`', () async {
      // TODO
    });


  });

}

==> pointpos_api-0.2.1.tar.gz: test/table_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';

// tests for Table
void main() {
  var instance = new Table();

  group('test Table', () {
    // String id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // String tableGroup (default value: null)
    test('to test the property `tableGroup`', () async {
      // TODO
    });

    // String name (default value: null)
    test('to test the property `name`', () async {
      // TODO
    });

    // num pax (default value: null)
    test('to test the property `pax`', () async {
      // TODO
    });

    // String shape (default value: null)
    test('to test the property `shape`', () async {
      // TODO
    });

    // TableLocation location (default value: null)
    test('to test the property `location`', () async {
      // TODO
    });

    // DateTime createdAt (default value: null)
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // String createdBy (default value: null)
    test('to test the property `createdBy`', () async {
      // TODO
    });

    // DateTime updatedAt (default value: null)
    test('to test the property `updatedAt`', () async {
      // TODO
    });

    // String updatedBy (default value: null)
    test('to test the property `updatedBy`', () async {
      // TODO
    });

    // bool deleted (default value: false)
    test('to test the property `deleted`', () async {
      // TODO
    });


  });

}
